File

Struct File 

pub struct File { /* private fields */ }
A view into a file on the filesystem.

An instance of File can be read or written to depending on the options it was opened with. Files also implement Seek to alter the logical cursor position of the internal file.

This struct is a single element tuple containing a std::fs::File that implements rsfs::File and has unix extensions.

Examples

let fs = rsfs::disk::FS;
let mut f = fs.create_file("f").await?;
assert_eq!(f.write(&[1, 2, 3]).await?, 3);